jactorch.utils.init
===================

.. automodule:: jactorch.utils.init

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      init_main
      register_rng
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: init_main

.. autofunction:: register_rng


